Class: Compass::Engine
- Inherits:
-
Rails::Engine
- Object
- Rails::Engine
- Compass::Engine
- Defined in:
- lib/compass/engine.rb
Overview
Rails plugin to autoload compass features such as Menu.
Mounting this engine exposes the routes necessary to allow other apps
to integrate with this Rails application. See more in config/routes.rb.